  /****************************************************************************
  * Title                 :   BIG 7 SEG R click
  * Filename              :   Big7SEGAVR.c
  * Author                :   SP
  * Origin Date           :   21/11/2016
  *****************************************************************************/
  /**
  * @note Test configuration:
  * MCU:             ATMEGA32
  * Dev.Board:       EasyAVR v7 Connectivity
  * Oscillator:      8 MHz external
  * Ext. Modules:    BIG 7-SEG R Click
  * SW:              AVR 6.1.2
  * NOTES:
    - Place BIG 7-SEG R click board on mikroBUS slot 1
    - Place J5 in 3v3 position
    - Switch to right position switches SW5.4, SW5.5, SW5.6, SW6.3 and SW6.4
    - PWM: PD4  _TIMER1_CH_B
    - RESET: PA6
    - LATCH: PA5
  *
  /******************************************************************************
  * Includes
  *******************************************************************************/
   #include "7_Seg.h"
  /******************************************************************************
  * Preprocessor Constants
  *******************************************************************************/

  /******************************************************************************
  * Configuration Constants
  *******************************************************************************/

  /******************************************************************************
  * Macros
  *******************************************************************************/

  /******************************************************************************
  * Typedefs
  *******************************************************************************/

  /* Module Variable Definitions
  *******************************************************************************/
  sbit HC595_RES at PORTA6_bit;
  sbit HC595_LAT at PORTA5_bit;
  sbit HC595_PWM at PORTD4_bit;
  
  sbit HC595_RES_Direction at DDA6_bit;
  sbit HC595_LAT_Direction at DDA5_bit;
  sbit HC595_PWM_Direction at DDD4_bit;
  /******************************************************************************

  /******************************************************************************
  * Function Definitions
  *******************************************************************************/
  extern char dig_array[MAX_CHARACTERS];

  // Variables
  unsigned short counter;
  unsigned int luminosity;
  unsigned int pwm_period;
  int8_t valid;

  char demo_array[20] =
  { 'M', 'I', 'K', 'R', 'O',
    'E', 'L', 'E', 'K', 'T', 'R', 'O', 'N', 'I', 'K', 'A',
    '2', '0', '1', '6'
  };

  void main()
    {
     // MCU Init
     HC595_PWM_Direction = 1;
     HC595_RES_Direction = 1;
     HC595_LAT_Direction = 1;

     // Initialize SPI
     SPI1_Init_Advanced( _SPI_MASTER, _SPI_FCY_DIV32, _SPI_CLK_LO_LEADING);
     SPI_Set_Active(SPI1_Read, SPI1_Write); // Sets the SPI1 module active

     // PWM Init
     pwm_period = 256;
     PWM16bit_Init(_PWM16_PHASE_CORRECT_MODE_8BIT, 
                   _PWM16_PRESCALER_16bit_8, 
                   _PWM16_NON_INVERTED, 255, 1);
     PWM16bit_Start(_TIMER1);
     PWM16bit_Change_Duty(190, _TIMER1_CH_B);

      // 74HC595 Init
     HC595_LAT = 0;
     HC595_reset();

     // Init counter and segment luminosity
     counter = 0;
     luminosity = 0;
     
     // Endless loop
     while (1)
     {
       valid = seg_7_display(demo_array[counter]);
       PWM16bit_Change_Duty(190 - luminosity, _TIMER1_CH_B);
       Delay_ms(750);
       luminosity += 5;
       counter++;
       if (counter == 20)     
         counter = 0;  
       if (luminosity == 180)   
         luminosity = 0;      
     }
  }